@@ -31,7 +31,10 @@ greta_stash$numerical_messages <- c("is not invertible",
 #' @param n_cores the maximum number of CPU cores used by each sampler (see
 #'   details).
 #' @param verbose whether to print progress information to the console
-#' @param pb_update how regularly to update the progress bar (in iterations)
+#' @param pb_update how regularly to update the progress bar (in iterations).
+#'   If \code{pb_update} is less than or equal to \code{thin}, it will be set
+#'   to \code{thin + 1} to ensure at least one saved iteration per
+#'   \code{pb_update} iterations.
 #' @param one_by_one whether to run TensorFlow MCMC code one iteration at a
 #'   time, so that greta can handle numerical errors as 'bad' proposals (see
 #'   below).
@@ -144,7 +147,7 @@ greta_stash$numerical_messages <- c("is not invertible",
 #' # initial values can also be passed to optimisers:
 #' o <- opt(m2, initial_values = initials(variance = 1))
 #'
-#' # and you can return a list of the hessians for each of these parameters
+#' # and you can return a list of the Hessians for each of these parameters
 #' o <- opt(m2, hessians = TRUE)
 #' o$hessians
 #'
@@ -238,6 +241,7 @@ mcmc <- function(model,
 
   # now make it finite
   pb_update <- min(pb_update, max(warmup, n_samples))
+  pb_update <- max(pb_update, thin + 1)
 
   run_samplers(samplers = samplers,
                n_samples = n_samples,
@@ -756,8 +760,8 @@ print.initials <- function(x, ...) {
 #'   varying dimension, the \code{par} and \code{hessian} objects returned by
 #'   \code{opt()} are named lists, rather than a vector (\code{par}) and a
 #'   matrix (\code{hessian}), as returned by \code{\link[stats:optim]{optim()}}.
-#'   Because greta arrays may not be vectors, the hessians may not be matrices,
-#'   but could be higher-dimensional arrays. To return a hessian matrix covering
+#'   Because greta arrays may not be vectors, the Hessians may not be matrices,
+#'   but could be higher-dimensional arrays. To return a Hessian matrix covering
 #'   multiple model parameters, you can construct your model so that all those
 #'   parameters are in a vector, then split the vector up to define the model.
 #'   The parameter vector can then be passed to model. See example.
